summaryrefslogtreecommitdiffstats
path: root/libkcal/resourcecalendar.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkcal/resourcecalendar.h')
-rw-r--r--libkcal/resourcecalendar.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libkcal/resourcecalendar.h b/libkcal/resourcecalendar.h
index 03318737..ef1acb2d 100644
--- a/libkcal/resourcecalendar.h
+++ b/libkcal/resourcecalendar.h
@@ -386,10 +386,10 @@ class LIBKCAL_EXPORT ResourceCalendar : public KRES::Resource
virtual bool removeSubresource( const TQString& resource );
/**
* Add a subresource with the name @param resource and the tqparent
* id @param tqparent.
*/
- virtual bool addSubresource( const TQString& resource, const TQString& tqparent );
+ virtual bool addSubresource( const TQString& resource, const TQString& parent );
/**
* Returns the type of the subresource: "event", "todo" or "journal",
@@ -386,10 +386,10 @@ class LIBKCAL_EXPORT ResourceCalendar : public KRES::Resource
virtual bool removeSubresource( const TQString& resource );
/**
- * Add a subresource with the name @param resource and the tqparent
- * id @param tqparent.
+ * Add a subresource with the name @param resource and the parent
+ * id @param parent.
*/